==> pochy-0.2-src.tar.gz: pochy-0.2-src/MainAddressCheckDlg.cpp <==
// MainAddressCheckDlg.cpp : Cve[V t@C
//

#include "stdafx.h"
#include "pochy.h"
#include "MainAddressCheckDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CMainAddressCheckDlg _CAO


CMainAddressCheckDlg::CMainAddressCheckDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CMainAddressCheckDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CMainAddressCheckDlg)
		//  - ClassWizard ͂̈ʒuɃ}bsOp̃}Nǉ܂͍폜܂B
	//}}AFX_DATA_INIT
}


void CMainAddressCheckDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CMainAddressCheckDlg)
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CMainAddressCheckDlg, CDialog)
	//{{AFX_MSG_MAP(CMainAddressCheckDlg)
	ON_WM_CANCELMODE()
	ON_BN_CLICKED(IDC_MAIN_ADDRESS_CHECK_TO_BUTTON, OnToButton)
	ON_BN_CLICKED(IDC_MAIN_ADDRESS_CHECK_CC_BUTTON, OnCcButton)
	ON_BN_CLICKED(IDC_MAIN_ADDRESS_CHECK_BCC_BUTTON, OnBccButton)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CMainAddressCheckDlg bZ[W nh

BOOL CMainAddressCheckDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();
	
	this->m_check_list.SubclassDlgItem(IDC_MAIN_ADDRESS_CHECK_LIST, this);

	int i;
	for(i=0; i<m_to_array.GetSize(); i++){
		this->m_check_list.AddString("To: "+m_to_array.GetAt(i));
		if(i==0){
			this->m_check_list.SetCheck(i, TRUE);
		}
	}
	for(i=0; i<m_cc_array.GetSize(); i++){
		this->m_check_list.AddString("Cc: "+m_cc_array.GetAt(i));
	}
	for(i=0; i<m_bcc_array.GetSize(); i++){
		this->m_check_list.AddString("Bcc: "+m_bcc_array.GetAt(i));
	}

	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
}

void CMainAddressCheckDlg::OnCancelMode() 
{
	CDialog::OnCancelMode();
	//	TODO: ̈ʒuɏ̕⑫ǉĂ
}

CString CMainAddressCheckDlg::GetTo()
{
	CString buf;
	int i;
	for(i=0; i<m_to_array.GetSize(); i++){
		if(i==0){
			buf = m_to_array.GetAt(i);
		}else{
			buf += ","+m_to_array.GetAt(i);
		}
	}
	return buf;
}

CString CMainAddressCheckDlg::GetCc()
{
	CString buf;
	int i;
	for(i=0; i<m_cc_array.GetSize(); i++){
		if(i==0){
			buf = m_cc_array.GetAt(i);
		}else{
			buf += ","+m_cc_array.GetAt(i);
		}
	}
	return buf;
}

CString CMainAddressCheckDlg::GetBcc()
{
	CString buf;
	int i;
	for(i=0; i<m_bcc_array.GetSize(); i++){
		if(i==0){
			buf = m_bcc_array.GetAt(i);
		}else{
			buf += ","+m_bcc_array.GetAt(i);
		}
	}
	return buf;
}

void CMainAddressCheckDlg::OnOK() 
{
	CString buf;
	this->m_to_array.RemoveAll();
	this->m_cc_array.RemoveAll();
	this->m_bcc_array.RemoveAll();

	for(int i=0; i<this->m_check_list.GetCount(); i++){
		if(!this->m_check_list.GetCheck(i)){
			continue;
		}
		this->m_check_list.GetText(i, buf);
		if(buf.Find("To: ") == 0){
			this->m_to_array.Add(buf.Mid(4));
		}else if(buf.Find("Cc: ") == 0){
			this->m_cc_array.Add(buf.Mid(4));
		}else if(buf.Find("Bcc: ") == 0){
			this->m_bcc_array.Add(buf.Mid(5));
		}
	}
	CDialog::OnOK();
}

void CMainAddressCheckDlg::SetTo(CString to)
{
	CString buf;
	int p;

	if(to.Find(",") == -1){
		m_to_array.Add(to);
	}else{
		while((p = to.Find(",")) != -1){
			buf = to.Left(p);
			buf.TrimRight(" ");
			buf.TrimLeft(" ");
			m_to_array.Add(buf);
			if(p+1 < to.GetLength()){
				to = to.Mid(p+1);
			}else{
				to.Empty();
			}
		}
		if(!to.IsEmpty()){
			to.TrimRight(" ");
			to.TrimLeft(" ");
			m_to_array.Add(to);
		}
	}
}

void CMainAddressCheckDlg::SetCc(CString cc)
{
	CString buf;
	int p;

	if(cc.Find(",") == -1){
		m_cc_array.Add(cc);
	}else{
		while((p = cc.Find(",")) != -1){
			buf = cc.Left(p);
			buf.TrimRight(" ");
			buf.TrimLeft(" ");
			m_cc_array.Add(buf);
			if(p+1 < cc.GetLength()){
				cc = cc.Mid(p+1);
			}else{
				cc.Empty();
			}
		}
		if(!cc.IsEmpty()){
			cc.TrimRight(" ");
			cc.TrimLeft(" ");
			m_cc_array.Add(cc);
		}
	}
}

void CMainAddressCheckDlg::SetBcc(CString bcc)
{
	CString buf;
	int p;

	if(bcc.Find(",") == -1){
		m_bcc_array.Add(bcc);
	}else{
		while((p = bcc.Find(",")) != -1){
			buf = bcc.Left(p);
			buf.TrimRight(" ");
			buf.TrimLeft(" ");
			m_bcc_array.Add(buf);
			if(p+1 < bcc.GetLength()){
				bcc = bcc.Mid(p+1);
			}else{
				bcc.Empty();
			}
		}
		if(!bcc.IsEmpty()){
			bcc.TrimRight(" ");
			bcc.TrimLeft(" ");
			m_bcc_array.Add(bcc);
		}
	}
}

void CMainAddressCheckDlg::OnToButton() 
{
	CString buf;

	int count = this->m_check_list.GetSelCount();
	int *sel = new int[count];
	count = this->m_check_list.GetSelItems(count, sel);
	for(int i=0; i<count; i++){
		this->m_check_list.GetText(sel[i], buf);
		this->m_check_list.SetCheck(sel[i], TRUE);
		if(buf.Find("Cc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "To: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}else if(buf.Find("Bcc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "To: "+buf.Mid(5));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}
	}
	delete [] sel;
}

void CMainAddressCheckDlg::OnCcButton() 
{
	CString buf;

	int count = this->m_check_list.GetSelCount();
	int *sel = new int[count];
	count = this->m_check_list.GetSelItems(count, sel);
	for(int i=0; i<count; i++){
		this->m_check_list.GetText(sel[i], buf);
		this->m_check_list.SetCheck(sel[i], TRUE);
		if(buf.Find("To: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Cc: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}else if(buf.Find("Bcc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Cc: "+buf.Mid(5));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}
	}
	delete [] sel;
}

void CMainAddressCheckDlg::OnBccButton() 
{
	CString buf;

	int count = this->m_check_list.GetSelCount();
	int *sel = new int[count];
	count = this->m_check_list.GetSelItems(count, sel);
	for(int i=0; i<count; i++){
		this->m_check_list.GetText(sel[i], buf);
		this->m_check_list.SetCheck(sel[i], TRUE);
		if(buf.Find("To: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Bcc: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}else if(buf.Find("Cc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Bcc: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}
	}
	delete [] sel;	
}

==> pochy-0.2.1-src.tar.gz: pochy-0.2.1-src/MainAddressCheckDlg.cpp <==
// MainAddressCheckDlg.cpp : Cve[V t@C
//

#include "stdafx.h"
#include "pochy.h"
#include "MainAddressCheckDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CMainAddressCheckDlg _CAO


CMainAddressCheckDlg::CMainAddressCheckDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CMainAddressCheckDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CMainAddressCheckDlg)
		//  - ClassWizard ͂̈ʒuɃ}bsOp̃}Nǉ܂͍폜܂B
	//}}AFX_DATA_INIT
}


void CMainAddressCheckDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CMainAddressCheckDlg)
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CMainAddressCheckDlg, CDialog)
	//{{AFX_MSG_MAP(CMainAddressCheckDlg)
	ON_WM_CANCELMODE()
	ON_BN_CLICKED(IDC_MAIN_ADDRESS_CHECK_TO_BUTTON, OnToButton)
	ON_BN_CLICKED(IDC_MAIN_ADDRESS_CHECK_CC_BUTTON, OnCcButton)
	ON_BN_CLICKED(IDC_MAIN_ADDRESS_CHECK_BCC_BUTTON, OnBccButton)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CMainAddressCheckDlg bZ[W nh

BOOL CMainAddressCheckDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();
	
	this->m_check_list.SubclassDlgItem(IDC_MAIN_ADDRESS_CHECK_LIST, this);

	int i;
	for(i=0; i<m_to_array.GetSize(); i++){
		this->m_check_list.AddString("To: "+m_to_array.GetAt(i));
		if(i==0){
			this->m_check_list.SetCheck(i, TRUE);
		}
	}
	for(i=0; i<m_cc_array.GetSize(); i++){
		this->m_check_list.AddString("Cc: "+m_cc_array.GetAt(i));
	}
	for(i=0; i<m_bcc_array.GetSize(); i++){
		this->m_check_list.AddString("Bcc: "+m_bcc_array.GetAt(i));
	}

	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
}

void CMainAddressCheckDlg::OnCancelMode() 
{
	CDialog::OnCancelMode();
	//	TODO: ̈ʒuɏ̕⑫ǉĂ
}

CString CMainAddressCheckDlg::GetTo()
{
	CString buf;
	int i;
	for(i=0; i<m_to_array.GetSize(); i++){
		if(i==0){
			buf = m_to_array.GetAt(i);
		}else{
			buf += ","+m_to_array.GetAt(i);
		}
	}
	return buf;
}

CString CMainAddressCheckDlg::GetCc()
{
	CString buf;
	int i;
	for(i=0; i<m_cc_array.GetSize(); i++){
		if(i==0){
			buf = m_cc_array.GetAt(i);
		}else{
			buf += ","+m_cc_array.GetAt(i);
		}
	}
	return buf;
}

CString CMainAddressCheckDlg::GetBcc()
{
	CString buf;
	int i;
	for(i=0; i<m_bcc_array.GetSize(); i++){
		if(i==0){
			buf = m_bcc_array.GetAt(i);
		}else{
			buf += ","+m_bcc_array.GetAt(i);
		}
	}
	return buf;
}

void CMainAddressCheckDlg::OnOK() 
{
	CString buf;
	this->m_to_array.RemoveAll();
	this->m_cc_array.RemoveAll();
	this->m_bcc_array.RemoveAll();

	for(int i=0; i<this->m_check_list.GetCount(); i++){
		if(!this->m_check_list.GetCheck(i)){
			continue;
		}
		this->m_check_list.GetText(i, buf);
		if(buf.Find("To: ") == 0){
			this->m_to_array.Add(buf.Mid(4));
		}else if(buf.Find("Cc: ") == 0){
			this->m_cc_array.Add(buf.Mid(4));
		}else if(buf.Find("Bcc: ") == 0){
			this->m_bcc_array.Add(buf.Mid(5));
		}
	}
	CDialog::OnOK();
}

void CMainAddressCheckDlg::SetTo(CStringArray &to)
{
/*	CString buf;
	int p;

	if(to.Find(",") == -1){
		m_to_array.Add(to);
	}else{
		while((p = to.Find(",")) != -1){
			buf = to.Left(p);
			buf.TrimRight(" ");
			buf.TrimLeft(" ");
			m_to_array.Add(buf);
			if(p+1 < to.GetLength()){
				to = to.Mid(p+1);
			}else{
				to.Empty();
			}
		}
		if(!to.IsEmpty()){
			to.TrimRight(" ");
			to.TrimLeft(" ");
			m_to_array.Add(to);
		}
	}*/
	m_to_array.Copy(to);
}

void CMainAddressCheckDlg::SetCc(CStringArray &cc)
{
/*	CString buf;
	int p;

	if(cc.Find(",") == -1){
		m_cc_array.Add(cc);
	}else{
		while((p = cc.Find(",")) != -1){
			buf = cc.Left(p);
			buf.TrimRight(" ");
			buf.TrimLeft(" ");
			m_cc_array.Add(buf);
			if(p+1 < cc.GetLength()){
				cc = cc.Mid(p+1);
			}else{
				cc.Empty();
			}
		}
		if(!cc.IsEmpty()){
			cc.TrimRight(" ");
			cc.TrimLeft(" ");
			m_cc_array.Add(cc);
		}
	}*/
	m_cc_array.Copy(cc);
}

void CMainAddressCheckDlg::SetBcc(CStringArray &bcc)
{
/*	CString buf;
	int p;

	if(bcc.Find(",") == -1){
		m_bcc_array.Add(bcc);
	}else{
		while((p = bcc.Find(",")) != -1){
			buf = bcc.Left(p);
			buf.TrimRight(" ");
			buf.TrimLeft(" ");
			m_bcc_array.Add(buf);
			if(p+1 < bcc.GetLength()){
				bcc = bcc.Mid(p+1);
			}else{
				bcc.Empty();
			}
		}
		if(!bcc.IsEmpty()){
			bcc.TrimRight(" ");
			bcc.TrimLeft(" ");
			m_bcc_array.Add(bcc);
		}
	}*/
	m_bcc_array.Copy(bcc);
}

void CMainAddressCheckDlg::OnToButton() 
{
	CString buf;

	int count = this->m_check_list.GetSelCount();
	int *sel = new int[count];
	count = this->m_check_list.GetSelItems(count, sel);
	for(int i=0; i<count; i++){
		this->m_check_list.GetText(sel[i], buf);
		this->m_check_list.SetCheck(sel[i], TRUE);
		if(buf.Find("Cc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "To: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}else if(buf.Find("Bcc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "To: "+buf.Mid(5));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}
	}
	delete [] sel;
}

void CMainAddressCheckDlg::OnCcButton() 
{
	CString buf;

	int count = this->m_check_list.GetSelCount();
	int *sel = new int[count];
	count = this->m_check_list.GetSelItems(count, sel);
	for(int i=0; i<count; i++){
		this->m_check_list.GetText(sel[i], buf);
		this->m_check_list.SetCheck(sel[i], TRUE);
		if(buf.Find("To: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Cc: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}else if(buf.Find("Bcc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Cc: "+buf.Mid(5));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}
	}
	delete [] sel;
}

void CMainAddressCheckDlg::OnBccButton() 
{
	CString buf;

	int count = this->m_check_list.GetSelCount();
	int *sel = new int[count];
	count = this->m_check_list.GetSelItems(count, sel);
	for(int i=0; i<count; i++){
		this->m_check_list.GetText(sel[i], buf);
		this->m_check_list.SetCheck(sel[i], TRUE);
		if(buf.Find("To: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Bcc: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}else if(buf.Find("Cc: ") == 0){
			this->m_check_list.DeleteString(sel[i]);
			this->m_check_list.InsertString(sel[i], "Bcc: "+buf.Mid(4));
			this->m_check_list.SetCheck(sel[i], TRUE);
		}
	}
	delete [] sel;	
}
